package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@(!`0````````````(`/@`!````("9```````!``````````.C*````
M`````````$``.``(`$``'0`<``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````.3$````````Y,0`````````
M`"````````$````&````Z,0```````#HQ&```````.C$8```````V`0`````
M``!8%0``````````(````````@````8````0Q0```````!#%8```````$,5@
M``````#P`0```````/`!````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%#E=&0$
M````3,````````!,P$```````$S`0```````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@```!(````$````%`````,```!'
M3E4`SKY<XYW1HWZC-/5[F+7CS8MNF"YA````=`````H``````````````$(`
M````````20```$@`````````'@```%P````^````.`````P````:````6```
M```````Q````80```%0```!&````;0```&D```!,````/P``````````````
M%P```%D````P``````````````!F````<@```&<````)````<````%$```!S
M````)@```$X`````````0P````````!Q`````````%````!!````````````
M``!H````"P`````````L``````````````!;````-````$0```!'````````
M```````\`````````$```````````````"4`````````(````!T````]````
M2P```"$```!2``````````````!=````;````#H````;````30```"\````S
M``````````T```````````````````!5````9`````````!%````7P```"D`
M```[````+@```#(`````````````````````````````````````````````
M````````````````````````````3P`````````$```````````````#````
M````````````````!0``````````````#P````````!@`````````!8`````
M``````````````!J`````````!``````````````````````````5@``````
M`````````````!\`````````5P`````````4```````````````G````"```
M````````````*`````X````U````8P```"(````5```````````````K````
M'````&X````1``````````<`````````:P```!(````M`````````%X````J
M`````````$H````&`````````````````````````````````````````%H`
M```D`````````&4`````````;P````$`````````&```````````````````
M`!,``````````````&(`````````&0````````!3````````````````````
M`````#8````"`````````",````Y````-P`````````E````3P````0````(
M````(!`0``5`!(:J`@`!@(8!J$(H`"!/(`0+N*(X3;J$!@I/````4```````
M`````````````%(```!4````50```%8```!7````6````%D```!:````7```
M`%T`````````7@```````````````````%\```!B``````````````!C````
M90```&8```!H`````````&H```!L``````````````!N````;P```'$`````
M````R=6R<<[>1RVCX/M)IMVC:^O3[PXOQ9NVV\WCGN?O7WN'^9R!:PE#UCGR
MBQP,.I<+1Y@%QL6)!9`-%.*>(?_D#K(!BV_$N9Q`:W^:?'^IG)MNQ=\?V7%8
M'+OCDGS49-1\K4OCP#)BV^WAIP(*9J_,9GOP2FOB1\8!0T75['U!CL7"Y3\L
MH2(+(/+;TQWZH6Q@N8WQ#@```````````````````````````````-<"```2
M`````````````````````````+$````2`````````````````````````*$!
M```2`````````````````````````*,#```2````````````````````````
M`.L"```2`````````````````````````'H"```2````````````````````
M`````(<#```2`````````````````````````!$````@````````````````
M`````````"`````@`````````````````````````(T!```2````````````
M```````````````$```2`````````````````````````#(#```2````````
M`````````````````&X!```2`````````````````````````(`!```2````
M`````````````````````"`#```2`````````````````````````!$#```2
M`````````````````````````#\#```2`````````````````````````)$"
M```2`````````````````````````"\$```2````````````````````````
M`"P"```2`````````````````````````/T````2````````````````````
M`````!P"```2`````````````````````````'(#```2````````````````
M`````````+$#```2`````````````````````````,H!```2````````````
M`````````````(X#```2`````````````````````````/<$```2````````
M`````````````````)@"```2`````````````````````````.H!```2````
M`````````````````````$<#```2`````````````````````````#4"```2
M`````````````````````````*8!```2`````````````````````````)P#
M```2`````````````````````````,D#```2````````````````````````
M`"\!```2`````````````````````````#0````2````````````````````
M`````-L#```2`````````````````````````#<#```2````````````````
M`````````%T!```2`````````````````````````,@````2````````````
M`````````````/$"```2`````````````````````````*H#```2````````
M`````````````````$$!```2`````````````````````````/<#```2````
M`````````````````````%P"```2`````````````````````````+<#```2
M`````````````````````````!D$```2`````````````````````````+X#
M```2`````````````````````````$X"```2````````````````````````
M`/@"```2`````````````````````````*L!```2````````````````````
M`````&$#```2`````````````````````````"@$```2````````````````
M`````````)4#```2`````````````````````````.P````2````````````
M`````````````$(````2`````````````````````````/`#```2````````
M`````````````````-<````2`````````````````````````/X!```2````
M`````````````````````%D#```2`````````````````````````-$#```2
M`````````````````````````(4"```2``````````````````````````D#
M```2`````````````````````````%`!```2````````````````````````
M`%`#```2`````````````````````````!T!```2````````````````````
M`````"$$```2`````````````````````````'\#```2````````````````
M`````````$,"```2``````````````````````````<$```2````````````
M`````````````%0````2`````````````````````````-@!```2````````
M`````````````````&,````2`````````````````````````(\````2````
M``````````````````````\$```2`````````````````````````'D#```2
M`````````````````````````'@````2``````````````````````````L!
M```2`````````````````````````+<!```2````H"%`````````````````
M`(0%```2``X`L%!```````"X"@```````+`%```2``X``$E```````#+`0``
M`````$,$```A`!H`P,E@```````(`````````)D$```2``\`Z&!`````````
M`````````'$$```2``X`D$5````````%`````````#`%```2``X`(&!`````
M``")`````````$4%```1`!``8&1```````#J6P```````*`````2````@"-`
M`````````````````!L%```0`!D`F,E@`````````````````.D#```1`!H`
MR,E@```````(`````````!T%```@`!D`F,E@`````````````````$`%```1
M`!D`L,E@```````(`````````$($```A`!H`P,E@```````(`````````(\$
M```2``X`$&!````````"`````````*,%```2``X`P$Y```````#J`0``````
M`+4$```2``X`T#Y```````!,`````````$$$```1`!H`P,E@```````(````
M`````#P$```2``X`D$Q````````K`@```````.4$```2``X`T$I````````B
M```````````%```2``X`$$Q```````!_`````````&`$```0`/'_P,E@````
M`````````````&P$```0`/'_0-I@`````````````````)\$```2``X`<%M`
M``````#W`P````````P%```1`!```&%````````$`````````"$%```2``X`
M("9``````````````````,,$```2``X`L$1```````#<`````````-D$```2
M``X``$M````````"`0```````&H"```2````<"-``````````````````(($
M```2``X`$"=````````T`````````%D$```0`/'_P,E@````````````````
M`%0%```2``X`<$!```````!``````````"@%```2``X`<%]````````M````
M`````'`%```1`!D`N,E@```````(`````````*,"```1`!H`T,E@```````3
M`````````)$%```2``X`T$=````````D`0```````"H%```2``P`""%`````
M``````````````!L:6)P97)L+G-O+C4N,3``7U]G;6]N7W-T87)T7U\`7TIV
M7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?27-T871B=69?
M<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?<'1R`%!E<FQ?
M<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!097)L7V%T9F]R
M:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C;VYS=')U8W0`
M4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T<@!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E;G9?<'1R`%!E
M<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W4U9P=@!0
M97)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?26]P7W!T
M<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L7VUG7W-E=`!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7T=T:')?:V5Y
M7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?9&5S=')U8W1?
M;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW
M:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV
M`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P
M96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`
M7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC;7``7U]S=')D
M=7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US
M970`<W1R<W1R`')M9&ER`&UE;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`7U]X
M<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``9G!R:6YT9@!R96%D9&ER-C0`;65M;6]V90!A8V-E<W,`<W1R8VUP
M`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E
M9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A
M<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`
M<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA
M;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/
M7W-T9&EN7W5S960`7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I
M;FET`&YA;65?;&]A9%]M>5]P87)?<&P`6%-?26YT97)N86QS7U!!4E]#3$5!
M4E-404-+`'-I>F5?;&]A9%]M>5]P87)?<&P`<&%R7VUK=&UP9&ER`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?
M,BXT`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C(N-0`````"````
M```#``(````#``````````,``P``````!``"``,``P`#``````````,``P``
M``,``P```````P````,``P`#```````%``,```````(``P````,````#``,`
M`P````(````&``,``P```````P```````P`#`````@````,````#``,````#
M`````````````P`#``````````$``0`#``$``0`!``$````!``,``0`!``,`
M`0`!``$``P`!``$``0`!``$``0`!``$``0`!`````0`!``$``0`!`````0`!
M``````````$`!``6`P``$````%`````4:6D-```&`+T%```0````$VEI#0``
M!0#'!0``$````'(9:0D```0`T04``!````!U&FD)```#`-T%`````````0`!
M`,<"```0`````````'4::0D```(`W04`````````QV````````8````(````
M``````````#`R6````````4```!@``````````````#(R6````````4```!9
M``````````````#0R6````````4```!Q```````````````@QV````````<`
M```!```````````````HQV````````<````"```````````````PQV``````
M``<````#```````````````XQV````````<````$``````````````!`QV``
M``````<````%``````````````!(QV````````<````&``````````````!0
MQV````````<````'``````````````!8QV````````<```!/````````````
M``!@QV````````<````*``````````````!HQV````````<````+````````
M``````!PQV````````<````,``````````````!XQV````````<````-````
M``````````"`QV````````<````.``````````````"(QV````````<````/
M``````````````"0QV````````<````0``````````````"8QV````````<`
M```1``````````````"@QV````````<````2``````````````"HQV``````
M``<````3``````````````"PQV````````<````4``````````````"XQV``
M``````<````5``````````````#`QV````````<````6``````````````#(
MQV````````<````7``````````````#0QV````````<````8````````````
M``#8QV````````<````9``````````````#@QV````````<````:````````
M``````#HQV````````<````;``````````````#PQV````````<````<````
M``````````#XQV````````<````=````````````````R&````````<````>
M```````````````(R&````````<````?```````````````0R&````````<`
M```@```````````````8R&````````<````A```````````````@R&``````
M``<````B```````````````HR&````````<````C```````````````PR&``
M``````<````D```````````````XR&````````<````E``````````````!`
MR&````````<```!K``````````````!(R&````````<```!7````````````
M``!0R&````````<````F``````````````!8R&````````<````G````````
M``````!@R&````````<````H``````````````!HR&````````<````I````
M``````````!PR&````````<````J``````````````!XR&````````<````K
M``````````````"`R&````````<````L``````````````"(R&````````<`
M```M``````````````"0R&````````<````N``````````````"8R&``````
M``<````O``````````````"@R&````````<````P``````````````"HR&``
M``````<````Q``````````````"PR&````````<````R``````````````"X
MR&````````<````S``````````````#`R&````````<````T````````````
M``#(R&````````<````U``````````````#0R&````````<````V````````
M``````#8R&````````<````W``````````````#@R&````````<````X````
M``````````#HR&````````<````Y``````````````#PR&````````<````Z
M``````````````#XR&````````<````[````````````````R6````````<`
M```\```````````````(R6````````<````]```````````````0R6``````
M``<````^```````````````8R6````````<````_```````````````@R6``
M``````<```!````````````````HR6````````<```!!```````````````P
MR6````````<```!"```````````````XR6````````<```!#````````````
M``!`R6````````<```!$``````````````!(R6````````<```!%````````
M``````!0R6````````<```!&``````````````!8R6````````<```!'````
M``````````!@R6````````<```!(``````````````!HR6````````<```!)
M``````````````!PR6````````<```!*``````````````!XR6````````<`
M``!+``````````````"`R6````````<```!,``````````````"(R6``````
M``<```!-``````````````"0R6````````<```!.``````````````!(@^P(
MZ#L%``#HR@4``.B5/P``2(/$",/_->JE(`#_)>RE(``/'T``_R7JI2``:```
M``#IX/____\EXJ4@`&@!````Z=#_____)=JE(`!H`@```.G`_____R72I2``
M:`,```#IL/____\ERJ4@`&@$````Z:#_____)<*E(`!H!0```.F0_____R6Z
MI2``:`8```#I@/____\ELJ4@`&@'````Z7#_____):JE(`!H"````.E@____
M_R6BI2``:`D```#I4/____\EFJ4@`&@*````Z4#_____)9*E(`!H"P```.DP
M_____R6*I2``:`P```#I(/____\E@J4@`&@-````Z1#_____)7JE(`!H#@``
M`.D`_____R5RI2``:`\```#I\/[___\E:J4@`&@0````Z>#^____)6*E(`!H
M$0```.G0_O___R5:I2``:!(```#IP/[___\E4J4@`&@3````Z;#^____)4JE
M(`!H%````.F@_O___R5"I2``:!4```#ID/[___\E.J4@`&@6````Z8#^____
M)3*E(`!H%P```.EP_O___R4JI2``:!@```#I8/[___\E(J4@`&@9````Z5#^
M____)1JE(`!H&@```.E`_O___R42I2``:!L```#I,/[___\E"J4@`&@<````
MZ2#^____)0*E(`!H'0```.D0_O___R7ZI"``:!X```#I`/[___\E\J0@`&@?
M````Z?#]____)>JD(`!H(````.G@_?___R7BI"``:"$```#IT/W___\EVJ0@
M`&@B````Z<#]____)=*D(`!H(P```.FP_?___R7*I"``:"0```#IH/W___\E
MPJ0@`&@E````Z9#]____);JD(`!H)@```.F`_?___R6RI"``:"<```#I</W_
M__\EJJ0@`&@H````Z6#]____):*D(`!H*0```.E0_?___R6:I"``:"H```#I
M0/W___\EDJ0@`&@K````Z3#]____)8JD(`!H+````.D@_?___R6"I"``:"T`
M``#I$/W___\E>J0@`&@N````Z0#]____)7*D(`!H+P```.GP_/___R5JI"``
M:#````#IX/S___\E8J0@`&@Q````Z=#\____)5JD(`!H,@```.G`_/___R52
MI"``:#,```#IL/S___\E2J0@`&@T````Z:#\____)4*D(`!H-0```.F0_/__
M_R4ZI"``:#8```#I@/S___\E,J0@`&@W````Z7#\____)2JD(`!H.````.E@
M_/___R4BI"``:#D```#I4/S___\E&J0@`&@Z````Z4#\____)1*D(`!H.P``
M`.DP_/___R4*I"``:#P```#I(/S___\E`J0@`&@]````Z1#\____)?JC(`!H
M/@```.D`_/___R7RHR``:#\```#I\/O___\EZJ,@`&A`````Z>#[____)>*C
M(`!H00```.G0^____R7:HR``:$(```#IP/O___\ETJ,@`&A#````Z;#[____
M)<JC(`!H1````.F@^____R7"HR``:$4```#ID/O___\ENJ,@`&A&````Z8#[
M____);*C(`!H1P```.EP^____R6JHR``:$@```#I8/O___\EHJ,@`&A)````
MZ5#[____)9JC(`!H2@```.E`^____R62HR``:$L```#I,/O___\EBJ,@`&A,
M````Z2#[____)8*C(`!H30```.D0^____R5ZHR``:$X```#I`/O__S'M28G1
M7DB)XDB#Y/!05$G'P!!@0`!(Q\$@8$``2,?'D$Q``.CW^___])"02(/L"$B+
M!:F@(`!(A<!T`O_02(/$",.0D)"0D)"0D)"0D)"054B)Y5-(@^P(@#UHHR``
M`'5+NP#%8`!(BP5BHR``2('K^,1@`$C!^P-(@^L!2#G8<R1F#Q]$``!(@\`!
M2(D%/:,@`/\4Q?C$8`!(BP4OHR``2#G8<N+&!1NC(``!2(/$"%O)PV9F9BX/
M'X0``````%5(@ST?GB```$B)Y702N`````!(A<!T"+\(Q6``R?_@R<.0D)"0
MD)"0D)"0D)"0D`^V#TB)^(3)="A(BP7W.P``2(U7`0^V,$B)^`\?1```0#CQ
M#[8*2`]$PDB#P@&$R77N\\-F9F8N#Q^$``````!53(U/.#')4TB![!`"``!(
MC70DB`\?0`!)BQ0)2(G028G02,'@"$G!X!A!@^#_)0``_P!,"<!)B=!)P>@(
M08'@`/\``$P)P$F)T$G!Z!A!@>#_````3`G`28G02<'H($B)!$Y,B<!)P>`8
M2,'@"$&#X/\E``#_`$P)P$F)T$C!ZCA)P>@H08'@`/\``$P)P$@)T$B)1$X(
M2(/!"$B#^4`/A7/___](C59H2('&:`(``$B+0MA(,P)(,T*H2#-"F$B)P4@!
MP$C!Z1]("<&#X?](B4H82(/""$@Y\G743(L'2(M/($@#3"2(2(M7"$B+7Q!(
MBW<83(G`3(G%2,'E!4C!Z!M(">B#X/],C90!F7F"6DB)T$B)V4CWT$@AT4@A
M\$@#="202`G(3(G!00'"2(G02,'B'DC!Z`)(]]%("=!((=E(`UPDF(/@_TB)
MPDPAPD@)RDR)T4R-C!:9>8):3(G22,'A!4C!ZAM,B=9("<I,B<%&C0P*3(G"
M2,'I`DC!XAY("=%,B=),B<V#X?](]])((<Y((<)("?)(C;03F7F"6DR)RDR)
MRTC!XP5(P>H;2`G:3(G+C30R3(G22<'B'DC!Z@)(]]-,"=)(`T0DH$@ARX/B
M_T@#3"2H2"'52`GK2(GU3(V4&)EY@EI(B?!(B?-(P>,%2,'H&T@)V$B)\T:-
M%!!,B<A)P>$>2,'H`DCWTTP)R$@ATT@#5"2P@^#_2"'%2`GK3(V,&9EY@EI,
MB=%,B=-(P>,%2,'I&T@)V4R)TT:-#`E(B?%(P>8>2,'I`DCWTT@)\4R)UD@A
MPX/A_TR)S4@ASD@)\TB-M!J9>8):3(G*3(G+2,'C!4C!ZAM("=I,B<N--#),
MB=))P>(>2,'J`DCWTTP)TD@#1"2X2"'+@^+_2`-,),!((=5(">M(B?5,C908
MF7F"6DB)\$B)\TC!XP5(P>@;2`G82(GS1HT4$$R)R$G!X1Y(P>@"2/?33`G(
M2"'32`-4),B#X/]((<5(">M,C8P9F7F"6DR)T4R)TTC!XP5(P>D;2`G93(G3
M1HT,"4B)\4C!YAY(P>D"2/?32`GQ3(G62"'#@^'_3(G-2"'.2`GS2(VT&IEY
M@EI,B<I,B<M(P>,%2,'J&T@)VDR)RXTT,DR)TDG!XAY(P>H"2/?33`G22`-$
M)-!((<N#XO](`TPDV$@AU4@)ZTB)]4R-E!B9>8):2(GP2(GS2,'C!4C!Z!M(
M"=A(B?-&C1003(G(2<'A'DC!Z`)(]]-,"<A((=-(`U0DX(/@_T@AQ4@)ZTR-
MC!F9>8):3(G13(G32,'C!4C!Z1M("=E,B=-&C0P)2(GQ2,'F'DC!Z0)(]]-(
M"?%,B=9((<.#X?],B<U((<Y("?-(C;0:F7F"6DR)RDR)RTC!XP5(P>H;2`G:
M3(G+C30R3(G22<'B'DC!Z@)(]]-,"=)(`T0DZ$@ARX/B_T@#3"3P2"'52`GK
M2(GU3(V4&)EY@EI(B?!(B?-(P>,%2,'H&T@)V$B)\T:-%!!,B<A)P>$>2,'H
M`DCWTTP)R$@ATT@#5"3X@^#_2"'%2`GK3(V,&9EY@EI,B=%,B=-(P>,%2,'I
M&T@)V4R)TT:-#`E(B?%(P>8>2,'I`DCWTT@)\4R)UD@APX/A_TR)S4@ASD@)
M\TB-M!J9>8):3(G*3(G+2,'C!4C!ZAM("=I,B<N--#),B=))P>(>2,'J`DCW
MTTP)TD@#!"1((<N#XO](`TPD"$@AU4@)ZTB)]4R-E!B9>8):2(GP2(GS2,'C
M!4C!Z!M("=A(B?-&C1003(G(2<'A'DC!Z`)(]]-,"<A((=-(`U0D$(/@_T@A
MQ4@)ZTR-C!F9>8):3(G13(G32,'C!4C!Z1M("=E,B=-&C0P)2(GQ2,'F'DC!
MZ0)(]]-("?%,B=9((<.#X?],B<U((<Y("?-(C;0:F7F"6DR)RDR)RTC!XP5(
MP>H;2`G:3(G+C30R3(G22<'B'DC!Z@)(]]-,"=)(`T0D&$@ARX/B_T@#3"0@
M2"'52`GK2(VL&)EY@EI(B?!(B?-(P>,%2,'H&T@)V(GKC2P83(G(2<'A'DC!
MZ`)(B?-,"<A(]]-)B?&#X/]((=-(`U0D*$DAP4P)RTR-C!F9>8):2(GI2(GK
M2,'C!4C!Z1M("=E&C0P)2(GQ2,'F'DC!Z0)("?%,B<Z#X?](P>8%2(G+2#'#
M2#'K2(V<&J'KV6Y,B<I(P>H;2`GRC1P:2(GJ2,'E'DC!Z@)(">J#XO](`T0D
M,$B)UD@QSD@#3"0X3#'.2(VL,*'KV6Y(B=A(B=Y(P>8%2,'H&T@)\(GNC2PP
M3(G(2<'A'DC!Z`),"<A)B>F#X/])P>$%2(G&2#'62`-4)$!(,=Y(C;0QH>O9
M;DB)Z4C!Z1M,"<F--#%(B=E(P>,>2,'I`D@)V4F)\8/A_TG!X05(B<M(,<-(
M`T0D2$@QZTB-G!JAZ]EN2(GR2,'J&TP)RHT<&DB)ZDC!Y1Y(P>H"2`GJ28G9
M@^+_2(G52#'-2#'U2<'A!4@#3"102(VL**'KV6Y(B=A(P>@;3`G(08GI0HTL
M"$B)\$C!YAY(P>@"2`GP28GI@^#_2<'A!4B)QD@QUD@#5"182#'>2(VT,:'K
MV6Y(B>E(P>D;3`G)C30Q2(G92,'C'DC!Z0)("=E)B?&#X?])P>$%2(G+2#'#
M2`-$)&!(,>M(C9P:H>O9;DB)\DC!ZAM,"<J-'!I(B>I(P>4>2,'J`D@)ZDF)
MV8/B_TG!X05(B=5(,<U(,?5(C:PHH>O9;DB)V$C!Z!M,"<A!B>I(`TPD:$*-
M+!!(B?!(P>8>2,'H`D@)\$F)Z8/@_TG!X05(B<9(,=9(`U0D<$@QWDB-M#&A
MZ]EN2(GI2,'I&TP)R8TT,4B)V4C!XQY(P>D"2`G928GQ@^'_2<'A!4B)RT@Q
MPT@#1"1X2#'K2(V<&J'KV6Y(B?)(P>H;3`G*C1P:2(GJ2,'E'DC!Z@)(">I)
MB=F#XO])P>$%2(G52#'-2#'U2(VL**'KV6Y(B=A(P>@;3`G(08GI0HTL"$B)
M\$C!YAY(P>@"2`GP2`.,)(````!)B>F#X/])P>$%2(G&2#'62`.4)(@```!(
M,=Y(C;0QH>O9;DB)Z4C!Z1M,"<F--#%(B=E(P>,>2,'I`D@)V4F)\8/A_TG!
MX05(B<M(,<-(`X0DD````$@QZTB-G!JAZ]EN2(GR2,'J&TP)RHT<&DB)ZDC!
MY1Y(P>H"2`GJ28G9@^+_2<'A!4B)U4@QS4@#C"28````2#'U2(VL**'KV6Y(
MB=A(P>@;3`G(08GJ0HTL$$B)\$C!YAY(P>@"2`GP28GI@^#_2(G&2#'62<'A
M!4@#E"2@````2#'>2(VT,:'KV6Y(B>E(P>D;3`G)C30Q2(G92,'C'DC!Z0)(
M"=E)B?&#X?])P>$%2(G+2#'#2`.$)*@```!(,>M(C9P:H>O9;DB)\DC!ZAM,
M"<J-'!I(B>I(P>4>2,'J`D@)ZH/B_TB)U4@QS4@#C"2P````2#'U3(V,**'K
MV6Y(B=A(B=U(P>4%2,'H&T@)Z$:-#`A(B?!(P>8>2,'H`D@)\(/@_TB)QD@Q
MUD@QWDB-K#&AZ]EN3(G)3(G.2,'I&TC!Y@5(`Y0DN````$@)\8GNC2PQ2(G>
M2,'C'DC![@)("=Z#YO](B?%(,<%(`X0DP````$PQR4B-G`JAZ]EN2(GJ2(GI
M2,'A!4C!ZAM("<I,B<E)P>$>2,'I`HT<&DP)R8/A_TB)RD@Q\D@QZDR-C!"A
MZ]EN2(G82(G:2,'B!4C!Z!M("=!(B>I(P>4>1HT,"$C!Z@*XW+P;CT@)ZDB)
MQ4@#K"3(````@^+_28G222'*2(UT-0!(B=5("<U((=U,"=5-B<I(C2PN3(G.
M2<'B!4C![AM,"=9!B>I"C2P62(G>2,'C'DC![@)("=Y(B<-(`YPDT````(/F
M_TF)\DDATDB-#`M(B?-("=-,(<M,"=-)B>I(C1P92(GI2<'B!4C!Z1M,"=&-
M'!E,B<E)P>$>2,'I`DP)R4F)P4P#C"38````@^'_28G*22'R28T4$4F)R4D)
M\4DAZ4T)T4F)VDZ-#`I(B=I)P>(%2,'J&TP)TD:-#`I(B>I(P>4>2,'J`D@)
MZDB)Q4@#K"3@````@^+_28G222'*2(UT-0!(B=5("<U((=U,"=5-B<I(C2PN
M3(G.2<'B!4C![AM,"=9!B>I"C2P62(G>2,'C'DC![@)("=Y(B<-(`YPDZ```
M`(/F_TF)\DDATDB-#`M(B?-("=-,(<M,"=-)B>I(C1P92(GI2<'B!4C!Z1M,
M"=&-'!E,B<E)P>$>2,'I`DP)R4F)P4P#C"3P````@^'_28G*22'R28T4$4F)
MR4D)\4DAZ4T)T4F)VDZ-#`I(B=I)P>(%2,'J&TP)TD:-#`I(B>I(P>4>2,'J
M`D@)ZDB)Q4@#K"3X````@^+_28G22(UT-0!(B=5("<U)(<I((=U,"=5-B<I(
MC2PN3(G.2<'B!4C![AM,"=9!B>I"C2P62(G>2,'C'DC![@)("=Y(B<-(`YPD
M``$``(/F_TF)\DDATDB-#`M(B?-("=-,(<M,"=-)B>I(C1P92(GI2<'B!4C!
MZ1M,"=&-'!E,B<E)P>$>2,'I`DP)R4F)P4P#C"0(`0``@^'_28G*22'R28T4
M$4F)R4D)\4DAZ4T)T4F)VDZ-#`I(B=I)P>(%2,'J&TP)TD:-#`I(B>I(P>4>
M2,'J`D@)ZDB)Q4@#K"00`0``@^+_28G222'*2(UT-0!(B=5("<U((=U,"=5-
MB<I(C2PN3(G.2<'B!4C![AM,"=9!B>I"C2P62(G>2,'C'DC![@)("=Y(B<-(
M`YPD&`$``(/F_TF)\DDATDB-#`M(B?-("=-,(<M,"=-)B>I(C1P92(GI2<'B
M!4C!Z1M,"=&-'!E,B<E)P>$>2,'I`DP)R4F)P4P#C"0@`0``@^'_28G*22'R
M28T4$4F)R4D)\4DAZ4T)T4F)VDZ-#`I(B=I)P>(%2,'J&TP)TD:-#`I(B>I(
MP>4>2,'J`D@)ZDB)Q4@#K"0H`0``@^+_28G222'*2(UT-0!(B=5("<U((=U,
M"=5-B<I(C2PN3(G.2<'B!4C![AM,"=9!B>I"C2P62(G>2,'C'DC![@)("=Y(
MB<-(`YPD,`$``(/F_TF)\DDATDB-#`M(B?-("=-,(<M,"=-)B>I(C1P92(GI
M2<'B!4C!Z1M,"=&-'!E,B<E)P>$>2,'I`DP)R4F)P4P#C"0X`0``@^'_28G*
M22'R28T4$4F)R4D)\4DAZ4T)T4F)VDZ-#`I(B=I)P>(%2,'J&TP)TD:-#`I(
MB>I(P>4>2,'J`D@)ZDB)Q4@#K"1``0``@^+_28G222'*2(UT-0!(B=5("<U(
M(=U,"=5-B<I(C2PN3(G.2<'B!4C![AM,"=9!B>I"C2P62(G>2,'C'DC![@)(
M"=Y(B<-(`YPD2`$``(/F_TF)\DDATDB-#`M(B?-("=-,(<M,"=-)B>I(C1P9
M2(GI2<'B!4C!Z1M,"=&-'!E,B<E)P>$>2,'I`DP)R4F)P4P#C"10`0``@^'_
M28G*28T4$4F)R4D)\4DA\DDAZ4T)T4F)VDZ-#`I(B=I)P>(%2,'J&TP)TD:-
M#`I(B>I(P>4>2,'J`D@)ZDB)Q4@#K"18`0``@^+_2`.$)&`!``!)B=))(<I(
MC70U`$B)U4@)S4B-#`A((=U,"=5-B<I(C2PN3(G.2<'B!4C![AM,"=9!B>I"
MC2P62(G>2,'C'DC![@)-B<I("=Y)P>H"@^;_2(GP2(GS2`G02"'33"'(2<'A
M'D@)V$B-'`%(B>A(B>E(P>$%2,'H&T@)R$T)RHT<&+C6P6+*08/B_TB)P4@#
MC"1H`0``28G92<'A!4B-%!%,B=%(,?%(,>E(C0P*2(G:2,'J&TP)RDF)Z4C!
MY1Y$C1P*2(G"2`.4)'`!``!)P>D"20GI3(G908/A_TC!X05(C30R3(G*3#'2
M2#':2(TL%DR)VDC!ZAM("<J)Z8TL"DB)V4C!XQY(P>D"2`G92(G#2`.<)'@!
M``"#X?](B>Y(B<I(P>8%3#'*3#':3`'32`'32(GJ2,'J&T@)\DB)QHT<&DR)
MVDG!XQY(P>H"3`G:@^+_2`.T)(`!``!.C0P.2(G62#'.2#'N38T<,4B)WDF)
MV4G!X05(P>X;3`G.1HT<'DB)[DC!Y1Y(P>X"2`GN2(G%2`.L)(@!``"#YO]-
MB=E)P>$%2(U,#0!(B?5(,=5(,=U(C2PI3(G92,'I&TP)R4&)Z4:-%`E(B=E(
MP>,>2,'I`D@)V4B)PT@#G"20`0``@^'_3(G52,'E!4B-%!-(B<M(,?-,,=M(
MC1P:3(G22,'J&T@)ZD2-#!I,B=I(B<-(`YPDF`$``$G!XQY(P>H"3`G:@^+_
M2(TT,TB)TT@QRTPQTTR-'!Y,B<M,B<Y(P>8%2,'K&T@)\TR)UDG!XAY&C1P;
M2(G#2`.<)*`!``!(P>X"3`G63(G=@^;_2,'E!4B-#`M(B?-(,=-,,<M(C1P9
M3(G92,'I&T@)Z42-%!E,B<E(B<-(`YPDJ`$``$G!X1Y(P>D"3`G)3(G5@^'_
M2,'E!4B-%!-(B<M(,?-,,=M(C1P:3(G22,'J&T@)ZD2-#!I,B=I(B<-(`YPD
ML`$``$G!XQY(P>H"3`G:@^+_2(TT,TB)TT@QRTPQTTR-'!Y,B<M,B<Y(P>8%
M2,'K&T@)\TR)UDG!XAY&C1P;2(G#2`.<)+@!``!(P>X"3`G63(G=@^;_2,'E
M!4B-#`M(B?-(,=-,,<M(C1P93(G92,'I&T@)Z42-%!E,B<E(B<-(`YPDP`$`
M`$G!X1Y(P>D"3`G)3(G5@^'_2,'E!4B-%!-(B<M(,?-,,=M(C1P:3(G22,'J
M&T@)ZD2-#!I,B=I(B<-(`YPDR`$``$G!XQY(P>H"3`G:@^+_2(TT,TB)TT@Q
MRTPQTTR-'!Y,B<M,B<Y(P>8%2,'K&T@)\TR)UDG!XAY(P>X"1HT<&TB)PTP)
MUD@#G"30`0``@^;_3(G=2,'E!4B-#`M(B?-(,=-,,<M(C1P93(G92,'I&T@)
MZ42-%!E,B<E(B<-(`YPDV`$``$G!X1Y(P>D"3`G)3(G5@^'_2,'E!4B-%!-(
MB<M(,?-,,=M(C1P:3(G22,'J&T@)ZD2-#!I,B=I(B<-(`YPDX`$``$G!XQY(
MP>H"3`G:@^+_2(TT,TB)TT@QRTPQTTR-'!Y,B<M,B<Y(P>8%2,'K&T@)\TR)
MUDG!XAY&C1P;2(G#2`.<).@!``!(P>X"3`G63(G=@^;_2(T,"TB)\T@QTTC!
MY05,,<M(C1P93(G92,'I&T@)Z42-%!E,B<E(B<-(`YPD\`$``$G!X1Y(P>D"
M3`G)3(G5@^'_2,'E!4B-%!-(B<M(,?-,,=M(C1P:3(G22,'J&T@)ZD2-#!I,
MB=I(B<-(`YPD^`$``$C!Z@))P>,>3`G:2`.$)``"``"#XO](C30S2(G32#'+
M2(T,"$PQTTB-+!Y,B<M,B<Y(P>8%2,'K&T@)\XGNC2PS3(G62<'B'DC![@),
MB<M,"=9-B<I(P>L"@^;_2<'B'DB)\$P)TT@QT$PQR$F)Z4@!P4B)Z$G!X05(
MP>@;3`G(`<A&C00`3(D'`V\(`U\0`W<8`U<@2(EO"$B)7Q!(B7<82(E7($B!
MQ!`"``!;7<,/'T0``$R)9"3@3(E\)/A)B?Q(B5PDT$B);"3828GW3(EL).A,
MB70D\$B#[#A(A?]U*S'`2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D*$R+?"0P
M2(/$.,-F#Q]$``!,BS6ABR``387V=,D/M@<\/71=A,!)B?UT5DF#Q0%!#[9%
M`#P]=`2$P'7O12GE28L>2(7;=)]-8^U,B?4/'T``3(GJ3(GF2(G?Z+KC__^%
MP'4'0H`\*SUT'TB#Q0A(BUT`2(7;==IFD.EH____#Q\`13'MZ[D/'P!,*?5*
MC40K`4C!_0-!B2_I2____V9F9BX/'X0``````$B#[!@QP$B-="0,Z`#___](
M@\08PV9F+@\?A```````2(/L"(L%SHH@`(/X_W0)2(/$",,/'T``,<"_!&%`
M`.B\____2(7`=!\/M@"$P'08/#`/E<`/ML")!9J*(`!(@\0(PP\?1```,<#K
M[`\?0`!52(G]4TB#[!A(C5PD#.L@2&-$)`Q(P>`#2`,%@(H@`$B#P`A(BQ!(
MA=)(B5#X=?`QP$B)WDB)[^AC_O__2(7`=<Y(@\086UW##Q^``````$B);"3H
M3(EL)/A(B?5(B5PDX$R)9"3P2('L.!```$F)U4B)YKK_#P``OPYA0`!D2(L$
M)2@```!(B80D"!```#'`Z#KD__^%P`^.B@```(U0_TQCXD*`/"0`='5,8^!,
MB>*^+P```$B)Y^BRX?__2(7`=&4Q_^C&Y?__BSCH/^'__TR)X4B)XDB)[DB)
MQ^C>X___2(N$)`@0``!D2#,$)2@```!U44B+G"08$```2(NL)"`0``!,BZ0D
M*!```$R+K"0P$```2('$.!```,,/'P"%TG6*#Q]``#'_Z&'E__^+..C:X/__
M3(GJ2(GN2(G'Z#SB___KG.@%Y/__#Q]$``!(@^P(,?_H->7__XLXZ*[@__^^
M_____TB)Q^AQXO__,?_H&N7__XLXZ)/@__\QTKZP0$``2(G'2(/$".E0Y?__
M4S'_Z/CD__^+..AQX/__2(G'Z'G@__](BP`Q_TB+6`CHV^3__XLXZ%3@__](
MB<?H_.#__P^V`#'_B$,@Z+_D__^+..@XX/__2(G'Z$#@__](BP`Q_TB+6`CH
MHN3__XLXZ!O@__](B<?HT^#__TB+`#'_#[=`(&8E_P%FB4,BZ'WD__^+..CV
MW___2(G'Z/[?__](BP`Q_TB+6`CH8.3__XLXZ-G?__\QTKZH8D``2(G'Z,KC
M__\Q_TB)0RCH/^3__XLXZ+C?__](B<?HP-___TB+`#'_2(M8".@BY/__BSCH
MF]___TB)Q^@3X/__2(L`,?](B4,PZ`7D__^+..A^W___2(G'Z(;?__](BP`Q
M_TB+6`CHZ./__XLXZ&'?__](B<?HR>+__S'22(,X`'0@,?_HRN/__XLXZ$/?
M__](B<?HJ^+__TB+`$B+D*@```!(B5,X,?_HIN/__XLXZ!_?__](B<?H)]__
M_TB+`#'_2(M`"$C'0$``````Z('C__^+..CZWO__2(G'Z`+?__](BP`Q_TB+
M0`A(QT!(`````.A<X___BSCHU=[__TB)Q^C=WO__2(L`,?](BU@(Z#_C__^+
M..BXWO__2(G'Z-#B__](BP!(B4-06\,/'X``````059!54%454B)_5-(@>R0
M````2(7_=`6`/P!U%$B!Q)````!;74%<05U!7L,/'T``Z&O@__](A<!(B<-T
MWP\?`$B)W^@(X___2(7`#X2O````3(UP$P^V%3(>```/MD`3.=`/A+@````/
MMA4>'@``.=`/A,D```!(B>_H$>#__TR)]TF)Q.@&X/__08U\!`)(8__H"=__
M_TR)\4B)QTF)Q$B)ZKX@84``,<#H4>#__TB)XDR)YK\!````Z+'A__^#^/]T
M%(M$)!@E`/```#T`0```#X28````3(GGZ!#?__],B>?HF-___TB)W^A@XO__
M2(7`#X58____#Q^``````$B)W^BHX?__2(GOZ/#>__](@<20````6UU!7$%=
M05[#00^V5@$Z%60=```/A`_____I,O___V8N#Q^$``````!!#[9&`3H%0QT`
M``^%)O___T$/MD8".@4S'0``#X3>_O__Z1#___]F#Q^$``````!,B>?HB/[_
M_^EC____#Q\`4TB)^S'_Z)7A__^+..@.W?__2(G'Z(;@__](B=Y(B<*_`0``
M`.CVW___A<!T"C'`6\-F#Q]$```Q_^AAX?__BSCHVMS__TB)Q^A2X/__BT`8
M)0#P```]`$```'0E,?_H/.'__XLXZ+7<__](B<?H+>#__XM`&"4`\```/0"@
M``!UK$B)W[X"````Z,'@__^%P`^4P`^VP%O##Q^``````$B)7"3H2(EL)/!,
MB60D^$B![#@@``!(C9PD$!```&1(BP0E*````$B)A"08(```,<#HRMW__[D9
M84``B<*^)F%``#'`2(G?Z)3>__^%P'E`,=M(BY0D&"```&1(,Q0E*````$B)
MV'5O2(N<)"`@``!(BZPD*"```$R+I"0P(```2('$."```,,/'X0``````+H`
M$```2(GF2(G?Z*#>__^%P$&)Q'BI08U\)`%(8__HS-S__TB%P$B)PW2636/D
M2(GF2(G'3(GBZ)/>__]"Q@0C`.E[____Z.3>__\/'T``Z1O___]F9BX/'X0`
M`````$B)7"302(EL)-@QP$R)9"3@3(EL).A(B?-,B70D\$R)?"3X2(/L2(`^
M/4F)_`^4P$@!PTB)W^A%W?__2(UT)`Q!B<5,B><QP.C3]___2(7`2(G%=%M(
MB<?H(]W__T2)ZD@YT`^"K0$```\?@``````/M@-(@\,!B$4`2(/%`83`=>XQ
MP$B+7"082(ML)"!,BV0D*$R+;"0P3(MT)#A,BWPD0$B#Q$C#9@\?A```````
M2(L]:8,@`#'MOA````!(@S\`2(GX="!F#Q^$``````!(@\`(@\4!2(,X`'7S
MC74"2&/V2,'F`XL%<X,@`(7`="?HVM[__TB%P$F)QDB)!1V#(`!,8_UU2[C_
M____Z7+___]F#Q]$``!(B??'!3N#(``!````Z&;;__](A<!)B<9TUDQC_4B+
M->2"(`!(B<=*C13]`````.@TW?__3(DUS8(@`$O'1/X(`````(EL)`Q!#[84
M)(#Z/0^$L0```(323(G@=0_II0```&8/'T0``(32=`Y(@\`!#[80@/H]9I!U
M[HGM12GE2,'E`T@#+7Z"(`!!C7P%`NCDVO__2(7`2(E%``^$3____XM4)`Q(
MBP5<@B``2(L4T$$/M@0DA,"(`G0D/#UT($F#Q`'K!P\?`#P]=!-!#[8$)$B#
MP@%)@\0!A,"(`G7IQ@(]2(/"`6:0#[8#2(/#`8@"2(/"`83`=>_I;/[__XML
M)`SI0?___TR)X.EK____9@\?A```````05=!5D%528G]051!O#QA0`!54[LR
M84``2(/L2$R+/2T;``!(QT0D$#QA0`!(QT0D&#)A0`!(C6PD($C'1"0@/V%`
M`$C'1"0H-6%``$C'1"0P.F%``$C'1"0XJ&)``.LG3(GN2(G'2(D$).B1V___
M2(7`=$R`.P!T-$B+10!)B=Q(@\4(2(G#,<!,B>?H3_;__TB%P'0%@#@`=<4Q
MP$R)[DR)Y^@H_?__@#L`=<Q(@\1(6UU!7$%=05Y!7\,/'T``3(GOZ(C:__],
MB?](B40D".A[VO__3(L$)$F)QDR)Q^ALVO__2(M4)`A*C7PR`4@!Q^AJV?__
M3(L$)$F)QDB)QTR)^4R)ZKY78D``,<#HKMK__TR)]DR)YS'`Z+'\___I4/__
M_V9F9BX/'X0``````$B#[#B_3&%``&1(BP0E*````$B)1"0H,<!(BP70&0``
M2(D$)$B+!<T9``!(B40D"$B+!<D9``!(B40D$$B+!<49``!(B40D&`^W!<$9
M``!FB40D(#'`Z,7U__\QP+]584``Z+GU__\QP+]=84``Z*WU__\QP+]F84``
MZ*'U__\QP+]M84``Z)7U__\QP+]]84``Z(GU__\QP+^)84``Z'WU__\QP+\$
M84``Z''U__\QP+^284``Z&7U__\QP+^<84``Z%GU__\QP+^F84``Z$WU__\Q
MP+^S84``Z$'U__\QP+^\84``Z#7U__\QP+_'84``Z+GT__](A<!T#TB)QK^2
M84``,<#HE?O__S'`O]AA0`#HF?3__TB%P'0/2(G&O^IA0``QP.AU^___,<"_
M]6%``.AY]/__2(7`=#Q(B<:_B6%``#'`Z%7[__\QP+XA8D``OVUA0`#H1/O_
M_TB+1"0H9$@S!"4H````=5I(@\0XPP\?@``````QP+\%8D``Z"ST__](A<!T
M%TB)QK\$84``,<#H"/O__^NQ9@\?1```2(UT)!&_%F)``+D*````\Z9UF$B-
M="0;OP1A0``QP.C<^O__ZX7HI=G__P\?1```2(/L".CGV?__B<?HX-?__TB)
MPC'`2(72=`-(BP)(@\0(PV9F9F9F+@\?A```````2(7_4TB)^W17@#\`=%+H
M#=C__TB-1`/_2#G##X/5````2(L]\!<```^V"`^V%SC1=`KK4`\?0``X"'5(
M2(/H`4@YPW+S2#G8=4X/M@`Z!P^$@P```%OIE=?__P\?1```OP(```#HQM;_
M_TB%P'0%9L<`+@!;PV8N#Q^$```````X$'3!2(/H`4@YPW+S2#G8=+AF#Q]$
M``!(@^@!2#G#<P</MA`Z%W3P2(G",<!(*=I(C4H"2('Y`!```'>W2(G>2(/"
M`;\@RF``Z"+9__^X(,I@`%O##Q\`OP(```#H3M;__TB)PC'`2(72=(AFQP(N
M`$B)T%O#2(L]&Q<``.E#____9F9F9F8N#Q^$``````!52(G]4TB#[`CHXO[_
M_P^V"$B)PX3)="I(BQ7I%@``#[8R2(U0`68N#Q^$``````!`./$/M@I(#T3:
M2(/"`83)=>XQP.AW\O__A<!T'4B%[708@'T``'02OB-B0`!(B=_H6]?__T@Y
MV'0'2(/$"%M=PTB#Q`A(B>];7>D!]O__D%-(@^P@B7PD'$B)="002(U\)!Q(
MB50D"$B-="002(U4)`CHZ=C__[J@(4``OX`C0`!(B=;H)Q,``#'_Z!#6__^`
M.`!U-NCVU?__2(7`2(D%/(T@``^$M@$``$B)Q^B^UO__,?_HM]C__XLXZ##4
M__](B<?HV-?__\8``#'_Z)[8__^+..@7U/__2(G'Z)_8__^`"`(Q_^B%V/__
MBSCH_M/__TB)Q^B&V/__@`@!BWPD'(/'!4AC_TB%_P^(&`$``/)(#RK'\@]8
M!>L6``!F#RX%ZQ8```^'/P$``$C!YP/HG-?__TB+="002(D%N(P@`$B+%DC'
M0`@H8D``2,=`$&!D0`!(QT`8*V)``$B)$(M\)!S'!82,(``$````@_\!?B.Z
M"````+D!````#Q]$``!(BQP6@\$!2(E<$!A(@\((.<]_[(U7!$4QP$B)P;Z@
M7T``2&/22,=$T/@`````C5<#2(L]*(P@`.B#T___A<")PW0]2(L]%HP@`.@Q
MUO__,<"_?6%``.B5\/__2(7`=#!(BSWYBR``Z"33___H']7__XG82(/$(%O#
M#Q^``````$B+/=F+(`#H!-3__XG#Z[-(BSW1BR``2(7_="GHK_W__^N]#Q]$
M``!(B?A(B?I(T>B#X@%("=#R2`\JP/(/6,#IT/[__[^)84``Z"'P__](A<!(
MB<=(B06,BR``=(+KO+\!````Z";3__^^T,E@`+\O84``,<#H%=;__P\?1```
M05=!5D%528GU051)B?R_B6%``%532('L*!```&1(BP0E*````$B)A"08$```
M,<#HO.___TB+'1T4``!,B>=(B<5(B=[HQ]3__TB%P'0[3(GFOZ9A0``QP.B#
M]O__2(N4)!@0``!D2#,4)2@```!,B>`/A6X!``!(@<0H$```6UU!7$%=05Y!
M7\-,B>?HS]/__TB+-<@3``!,B>^)1"0,Z"S5__](A<!)B<9THHM4)`Q,C6PD
M$$&_'F%``(/"`8E4)`QF#Q]$``!!@#X`30]$]TB%[7033(GV2(GOZ.#4__^%
MP`^$L````$R)]^APT___2&/000^V5!;_.A-U)8U0_TACTDF-%!9F#Q^$````
M```/MDK_Q@(`@^@!2(/J`3H+=.X#1"0,/?\/```/CQW___]-B>!(B=E,B?*^
M5V)``$R)[S'`Z(?3__\Q_^B@U?__BSCH&='__TB)Q^B1U/__3(GN2(G"OP$`
M``#HT=3__X7`=24Q_^AVU?__BSCH[]#__TB)Q^AGU/__BT`8)0#P```]`(``
M`'0?2(LUP1(``#'_Z"K4__](A<!)B<8/A1;____IE_[__[X!````3(GOZ-S4
M__^%P'703(GNOZ9A0`#H"_7__TR)[^A3TO__28G$Z7C^___HQM/__V8/'T0`
M`$%7059!54%455-(B?N_B6%``$B![!B"``!D2(L$)2@```!(B80D"((``#'`
M2,>$)``!```N8D``2,>$)`@!```V8D``2,>$)!`!```>84``2,>$)!@!``"H
M8D``2,>$)-````#J84``2,>$)-@```#C84``2,>$).`````[8D``2,>$).@`
M```Q8D``2,>$)/````!#8D``2,>$)/@```"H8D``2,>$)"`!``!'8D``2,>$
M)"@!``!,8D``2,>$)#`!``"H8D``Z#/M__](A<!T"8`X``^%I0,``#'`#Q\`
MZ#OY__](A<!)B<</A+<#``!!#[8O0(3M="KHL='__TR)^F8/'T0``$B+"$@/
MONWV!&D(=0/&`E](@\(!#[8J0(3M=>1(C:PDV````+_J84``ZQ8/'T0``$B+
M?0!(@\4(@#\`#X3G`@``,<#HL.S__TB%P$F)Q'3@2(G'Z`#R__^%P'343(GG
MZ-30__](A<!)B<9TQ$R)]^CTT/__3(G_2(G%Z.G0__^)ZD2-I`($!```36/D
M3(GGZ.3/__],B>=(B<7HV<___TR++;H0``!(B<=)B<1-B?E!N"-B0`!,B?*^
M56)``#'`3(GIZ!'1__^^P`$``$R)Y^ADT___@_C_#X3+`0``2(U4)$!,B>:_
M`0```.B)T?__@_C_#X0>"```BT0D6"4`\```/0!````/A=0!``!$BW0D7.CR
MT?__03G&#X7!`0``BT0D6"7_`0``/<`!```/A:T!```QP+\U84``Z+GK__](
MA<`/A*`"``!(B<?HZ,___TB+.TB)QNBM^___2(7`28G&#X2!`@``3(GWZ/G/
M__^#^`-^7$ACT+]>8D``N04```!)C706_/.F=4:#^`1T$8/H!$B800^V1`;_
M03I%`'4P2(M;"$B%VW0G2(G?Z+?/__](@_@#=AE(C70#_+]C8D``N04```#S
MIG0)9@\?1```3(GS,<!)B>[H.^O__X7`=18Q]DB)W^@=T/__A<")1"0L#X7Y
M`0``OB%B0`"_!&%``#'`Z.#Q___HZ\[__T&YJ&)``$&)P$R)Z4R)XKY\8D``
M2(GO,<`QV^BKS___ZSYF#Q^$``````#H6]#__X,X$74]@\,!Z*[.__]!B=E!
MB<!,B>E,B>*^BF)``$B)[S'`2,<$)*AB0`#H:\___[[``0``2(GOZ+[1__^#
M^/]TN4R)Y^C1SO__2(GNOXEA0``QP.A2\?__2(GOZ'KS___K7`\?A```````
MZ.O/__]$BP!!@_@1#Q]```^$'_[__TB+$TB+/4AU(`!,B>&^*&-``#'`13'V
MZ/[0___K(`\?0`!(BQ-(BSTF=2``3(GAOJ!C0``QP$4Q]NC<T/__2(N4)`B"
M``!D2#,4)2@```!,B?`/A94&``!(@<08@@``6UU!7$%=05Y!7\-,C:0D"`$`
M`+TN8D``ZQ.028LL)$F#Q`B`?0``#X0B_?__2(GO13'VZ`/O__^%P'3?2(GO
MZ-?-__](A<!)B<9TS^G^_/__9BX/'X0``````$B)QTB)1"00Z)/R__](BT0D
M$$B)Q^BFS?__28G&Z6+___]F#Q]$``!(C:PD*`$``+]'8D``#Q\`,<#H0>G_
M_TB%P'042(G'Z'3-__](A<!)B<</A1G\__](BWT`2(/%"(`_`'730;^;8D``
MZ33\__],BS/I=_W__[H"````2,?&[O___XG'Z&7/__],C;PD0`$``(M\)"RZ
M!@```$R)_N@\S/__@+PD0`$```!U#H"\)$$!``!##X0+!0``BWPD+#'2NXFK
MS>\Q]N@BS___2(F<)$B!``!(C9PD0($``+G^W+J8NO#ATL-(QX0D0($```$C
M16=(B8PD4($``$B->SA(QX0D6($``'94,A!(B90D8($``$C'A"1H@0``````
M`$C'A"1P@0```````,>$)+B!````````2(E\)#`/'T``BWPD++H`@```3(G^
MZ(_+__^%P(E$)"`/CI@!``!(8U0D($B+M"1H@0``2(N$)'"!``"+O"2X@0``
MC0S62#GQ2(F,)&B!``!,B?Y(@]``2,'J'4B)A"1P@0``2`&4)'"!``"%_W1J
MN4`````I^3E,)"!(8_\/3DPD($@#?"0P2&/!B4PD&$B)PDB)1"0XZ`[-__^+
MA"2X@0``BTPD&`'(@_A`B80DN($```^%4?___TB+5"0X2(G?*4PD($F--!=(
MB70D&.@7T/__2(MT)!AFD(-\)"`_#XZ[````,<`/'P!(BQ0&2(G?2(F4)'B!
M``!(BU0&"$B)E"2`@0``2(M4!A!(B90DB($``$B+5`882(F4))"!``!(BU0&
M($B)E"28@0``2(M4!BA(B90DH($``$B+5`8P2(F4)*B!``!(BU0&.$B)1"00
M2(ET)!A(B90DL($``.B'S___2(M$)!"+5"0@2(MT)!A(@\!`*<*#^C\/CVK_
M__^+5"0@@^I`B='!Z0:)R,'A!DC!X`8IRDB-=#!`B50D($AC5"0@2(M\)##H
M^\O__XM\)"")O"2X@0``Z4O^__^+?"0LZ$+)__],B[PD:($``$R+A"1P@0``
M3(GX2,'H`X/@/TACT(/``8/X.,:$%'B!``"`#X\F`@``NC@````Q]DR)1"00
M*<)(F$B-?`,X2&/2Z.3(__],BT0D$$R)P$B)WT2(O"2W@0``2,'H&$2(A"2S
M@0``2(V<),"!``"(A"2P@0``3(G`2,'H$(B$)+&!``!,B<!(P>@(B(0DLH$`
M`$R)^$C!Z!B(A"2T@0``3(GX2,'H$(B$)+6!``!,B?A,C;PD\8$``$C!Z`B(
MA"2V@0``Z%/.__](BX0D0($``$B)P8B$)/.!``!(P>D8B<J(C"3P@0``2(G!
M2,'I$(B,)/&!``!(B<%(BX0D2($``$C!Z0B(C"3R@0``2(G!B(0D]X$``$C!
MZ1B(C"3T@0``2(G!2,'I$(B,)/6!``!(B<%(BX0D4($``$C!Z0B(C"3V@0``
M2(G!B(0D^X$``$C!Z1B(C"3X@0``2(G!2,'I$(B,)/F!``!(B<%(BX0D6($`
M`$C!Z0B(C"3Z@0``2(G!B(0D_X$``$C!Z1B(C"3\@0``2(G!2,'I$(B,)/V!
M``!(B<%(BX0D8($``$C!Z0B(C"3^@0``2(G!B(0D`X(``$C!Z1B(C"0`@@``
M2(G!2,'I$(B,)`&"``!(B<%(B=A(P>D(2(/`*(B,)`*"``!(B40D(.L.9@\?
M1```00^V%TF#QP%(B=\QP`^VTKYW8D``2(/#`NA"R?__2#M<)"!UVTR-A"3`
M@0``QH0DZ($```!!N:AB0`!,B>E,B>*^:&)``$B)[S'`Z!#)___ILOG__TR-
M2SBZ0````#'V*<)(F$R)1"0028T\`4ACTDR)3"08Z+;&__](B=_HGLS__TR+
M3"08N0<````QP$R)S_-(JTR+1"00Z;/]___H?<G__TB+$T2+`$R)X4B+/>5N
M(`"^:&-``#'`13'VZ)[*___IO?G__X"\)$(!``!!#X7G^O__@+PD0P$``$,/
MA=GZ__^`O"1$`0``2`^%R_K__X"\)$4!``!%#X6]^O__BWPD++H"````2,?&
MQO___^C<R?__BWPD++HI````3(G^Z+O&__]!N:AB0`!-B?CI"/___^@(R?__
M#Q^$``````!!53'_05154TB#[`CH+\K__XLXZ*C%__](B<?HL,?__[]M84``
MQ@`!,<#H$>/__TB%P'0)@#@Q#X2C`@``,<"0Z$OM__\Q_^CTR?__BSCH;<7_
M_[D+````N@$```"^HF)``$B)Q^B6QO__2(7`#X2V````2(M`$#';O0@```!,
MBV`HBP4X?B``@_@!?S?IC````&8/'T0``$F+=1!(BP4E?B``2(L\*.ADR/__
MA<!U:(/#`8L%!WX@`$B#Q0B-4P$YPGU:,?_H=<G__XLXZ.[$__\QR8G:3(GF
M2(G'Z*_'__](A<!T,DR+*$'V10T$=:@Q_^A)R?__BSCHPL3__TR)[KD"````
M,=)(B<?HD,G__TB)QNN'#Q\`BP6B?2``C5#_.=H/A$\!```Q_^@0R?__BSCH
MB<3__[D%````N@$```"^IV)``$B)Q^BRQ?__2(7`2(G#=#9(BT`0,?](BRCH
MW,C__XLXZ%7$__^ZJ6)``$B)QTB)[NBUQ?__2(M#$$B+&/9##D`/A30!```Q
M_^BMR/__BSCH)L3__[D%````N@$```"^Q6%``$B)Q^A/Q?__2(7`2(G#=#LQ
MP+^F84``Z'OA__](A<!)B<0/A"<!``!(BT,0,?](BRCH8<C__XLXZ-K#__],
MB>)(B>Y(B<?H/,7__S'_Z$7(__^+..B^P___2(G'Z,;%__\Q_\8``.@LR/__
MBSCHI</__TB)Q^@]R/__OXEA0`!(QP``````,<#H"N'__TB%P$B)!7A\(``/
MA.0```"^[0$``$B)Q^@MR/__@_@1=`Z%P'0*@_C_D`^%*P$``$B#Q`A;74%<
M05W##Q^``````(/X`0^.J/[__[L!````9BX/'X0``````#'_@\,!Z*;'__^+
M..@?P___3(GF2(G'Z$3$__\Y'0Y\(`!_W.EP_O__#Q^``````#'_Z'G'__^+
M..CRPO__2(G>2(G'Z!?&___IKO[__V:0@'@!``^$6_W__V8/'T0``.E(_?__
M#Q\`2(L%R7L@`#'_3(L@2(M#$$B+*.@PQ___BSCHJ<+__TR)XDB)[DB)Q^C;
MX/__Z<K^__](BSV7>R``Z`KR__](B05[>R``2(M#$$B++8![(`!,BR!!]D0D
M#01T?TF+1"002(GN2(G'Z.W"__^)Q4B+0Q!(BQCV0PT$=#Y(BT,02(G"2(L%
M2'L@`(GIO\AC0`!(BS`QP.C/Q?__B<%(BP4N>R``2(L5%WL@`+_X8T``2(LP
M,<#HL,7__S'_Z(G&__^+..@"PO__N0(````QTDB)WDB)Q^C0QO__ZZ0Q_^AG
MQO__BSCHX,'__[D"````,=),B>9(B<?HKL;__^EA____9@\?A```````2(/L
M"#'_Z#7&__^+..BNP?__N:YB0`"Z<"-``+ZX8D``2(G'2(/$".GCQ?__#Q\`
M2(/L"#'_Z`7&__^+..A^P?__2(G'Z+;___\Q_^COQ?__BSCH:,'__T&XJ&)`
M`$4QR;IP6T``3(G!OM1B0`!(B<=(@\0(Z;;#__^0D)"0D)!(C06I:2``2(7`
M=`Q(BPV=:2``Z?C!__\QR>OWD)"0D//#9F9F9F8N#Q^$``````!(B6PDV$R)
M9"3@2(TMLV0@`$R-):QD(`!,B6PDZ$R)="3P3(E\)/A(B5PDT$B#[#A,*>5!
MB?U)B?9(P?T#28G7Z*/`__](A>UT'#';#Q]``$R)^DR)]D2)[T'_%-Q(@\,!
M2#GK<NI(BUPD"$B+;"003(MD)!A,BVPD($R+="0H3(M\)#!(@\0XPY"0D)"0
MD)!52(GE4TB#[`A(BP4H9"``2(/X_W09N^C$8``/'T0``$B#ZPC_T$B+`TB#
M^/]U\4B#Q`A;R<.0D$B#[`CH?\7__TB#Q`C#``````````````$``@!005)?
M0TQ%04X`+W!R;V,O<V5L9B]E>&4`+BX`)7,O)7,`+W!R;V,O)6DO)7,`3$E"
M4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!015),-4Q)0@!015),3$E"`%!%4DPU
M3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27U1%
M35``4$%27T1%0E5'`%!!4E]#04-(10!005)?4%)/1TY!344`4$%27T%21T,`
M4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2
M`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M4$%27T-,14%./0`Q`'!A<BT`+64`+2T`0SI<5$5-4``O=&UP`%1%35!$25(`
M5$U0`%5315(`55-%4DY!344`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H
M92TE<R5S`"4P,G@`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`%-9
M4U1%30!!4D=6`!@`<&5R;`!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"\`.@````!?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````Z6)```````#K8D``
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H````````E<SH@<W1A="!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4*```E<SH@97AE8W5T:6]N(&]F
M("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M
M(&%B;W)T:6YG('=I=&@@)6DN"@``````````````````````P$-P87(N<&P`
M`",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R
M:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@
M+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL
M93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP
M.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S
M97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI
M;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U
M;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@
M("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A
M;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD
M(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B
M86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE
M<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@
M("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R
M('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C
M;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@
M("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D
M=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64[
M"B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N
M=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T
M96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@
M)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI
M<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2![
M"B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D
M14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!]
M.PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE
M=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN
M=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@
M("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7
M:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@
M97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S
M+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A
M=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O
M<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S
M965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA
M<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(
M+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(
M+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D
M8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@
M(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y
M('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@
M(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@
M;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN
M9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D
M9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@
M("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*
M("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@
M("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D
M9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@
M("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*
M("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B
M87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE
M;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@
M("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@
M)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@
M("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*
M("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@
M("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@
M(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@
M("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@
M)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA
M<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E
M='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE
M;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I
M;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@
M("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G
M+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T
M*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@
M("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O
M<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@
M("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO
M="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@
M;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@
M<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R
M.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(
M96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R
M>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U
M:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I
M;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE
M8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F
M:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P
M('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U
M;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M
M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W
M*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL
M7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I
M9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I
M9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N
M<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@
M87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY
M=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E
M="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@
M(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@
M("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]
M('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H
M:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@
M*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN
M8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@
M("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@
M("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G
M<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@
M("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@
M("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@
M("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@
M("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2
M.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E
M8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L
M:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@
M("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@
M(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G
M)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@
M("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*
M"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@
M("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T
M82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N
M(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT
M.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@
M)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H
M4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N
M;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E
M4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@
M("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H
M*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S
M(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@
M/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@
M("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@
M(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@
M(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@
M("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G
M:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I
M*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I
M.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD
M;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q
M=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@
M("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@
M("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@
M("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@
M861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM
M97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI
M8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@
M9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@
M("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N
M9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I
M;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>
M7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@
M)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@
M("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I
M.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@
M("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@
M("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@
M*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D
M92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@
M("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@
M("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J
M(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^
M(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@
M("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP
M;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%
M(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*
M("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@
M("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@
M4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z
M.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B
M(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@
M("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U
M+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A
M<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N
M86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I
M="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@
M("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z
M("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!]
M(#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@
M("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@
M("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@
M("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*
M("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@
M/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@
M("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@
M("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]
M"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@
M=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T
M:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL
M93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA
M3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I
M8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@
M("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@
M<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@
M("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@
M(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z
M.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V
M86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M
M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2
M.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R
M7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]
M("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P
M871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%
M35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M
M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E
M<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@
M*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@
M/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@
M("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@
M("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@
M;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@
M("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@
M("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@
M("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N
M9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@
M("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE
M+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.
M5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I
M(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M
M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE
M;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]
M"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I
M(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R
M971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I
M;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P
M<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D
M<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*
M("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@
M("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@
M("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@
M('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@
M6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@
M("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@
M("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E
M;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H
M)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%
M04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@
M(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]
M"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H
M92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@
M;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64[
M"@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.1%]?"@````$;
M`SOH````'````,1F__\$`0``!&?__QP!``!T??__1`$``&1^__]L`0``A'[_
M_X0!``#4?O__G`$``"1___^\`0``)(#__]P!``!D@/__]`$``$2"__\,`@``
MQ(/__SP"``!DA/__5`(``$2%__]T`@``5(7__XP"``"$A___M`(``+2(___L
M`@``A(K__P0#``"TBO__'`,``,2+__\T`P``1(S__U0#``!TCO__=`,``&20
M__^L`P``))O__^0#```DG___#`0``%2?__\D!```I)___SP$``#$G___5`0`
M`-2?__]L!```%``````````!>E(``7@0`1L,!PB0`0``%````!P```"X9?__
M-```````````````)````#0```#@9?__:Q8```!!#A!'#AA'#J@$`I:#`X8"
M`````````"0```!<````*'S__^0`````38\"C`5;#D!%C@.-!(8&@P<`````
M```4````A````/!\__\5`````$0.(``````4````G````/A\__],`````$0.
M$``````<````M````#!]__])`````$$.$$.&`D$.&$0.,$6#`QP```#4````
M8'W___L`````38T"A@11#L`@8XP#@P4`%````/0```!`?O__0`````!$#A``
M````%`````P!``!H?O__V0$```!!#A!"@P(`+````"0!```P@/__?0$```!"
M#A!"#AA"#B!!#BA#A@6,!(T#C@)!#C!'#L`!18,&%````%0!``"`@?__F0``
M``!!#A!#@P(`'````&P!```(@O__W`````!6#L!`2(P"A@.#!``````4````
MC`$``,B"__\%```````````````D````I`$``,""__\G`@```%F-!(P%A@:#
M!TX.4$^/`HX#````````-````,P!``#(A/__)`$```!"#A!"#AA"#B!#C02.
M`X\"0@XH1HP%00XP00XX18,'A@9$#H`!```4````!`(``,"%___+`0```$0.
M0``````4````'`(``'B'__\B`````$0.$``````4````-`(``)"'__\"`0``
M`$0.$$.#`@`<````3`(``(B(__]_`````$$.$$.&`D$.&$0.((,#`!P```!L
M`@``Z(C__RL"````00X01`XP78,"````````-````(P"``#XBO__Z@$```!"
M#A!"#AA"#B!#C02.`X\"0@XH0XP%1@XP00XX1P[@(%.#!X8&```T````Q`(`
M`+",__^X"@```$(.$$(.&$(.($(.*$$.,$$..$.#!X8&C`6-!(X#CP),#M"$
M`@```"0```#\`@``.)?___<#````0@X01`X800X@00XH1`XP@P6&!(P#C0(4
M````)`,``!";__\M`````$0.$``````4````/`,``"B;__]*`````$0.$```
M```4````5`,``&";__\<```````````````4````;`,``&B;__\"````````
M```````D````A`,``&";__^)`````%&,!88&7PY`1H,'CP*.`XT$````````
M``````````#__________P``````````__________\`````````````````
M`````0`````````!``````````$`````````L@(````````!`````````+T"
M`````````0````````#'`@````````$`````````%@,````````!````````
M`$L$````````#``````````((4````````T`````````Z&!````````$````
M`````&`"0```````]?[_;P````#`!4````````4`````````^!%````````&
M`````````!@'0```````"@````````#I!0````````L`````````&```````
M```5`````````````````````P`````````(QV````````(`````````:`<`
M```````4``````````<`````````%P````````"@&4````````<`````````
M0!E````````(`````````&``````````"0`````````8`````````/[__V\`
M````T!A```````#___]O``````(`````````\/__;P````#B%T``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````$,5@````````````````````````````-B%```````!&
M(4```````%8A0```````9B%```````!V(4```````(8A0```````EB%`````
M``"F(4```````+8A0```````QB%```````#6(4```````.8A0```````]B%`
M```````&(D```````!8B0```````)B)````````V(D```````$8B0```````
M5B)```````!F(D```````'8B0```````AB)```````"6(D```````*8B0```
M````MB)```````#&(D```````-8B0```````YB)```````#V(D````````8C
M0```````%B-````````F(T```````#8C0```````1B-```````!6(T``````
M`&8C0```````=B-```````"&(T```````)8C0```````IB-```````"V(T``
M`````,8C0```````UB-```````#F(T```````/8C0```````!B1````````6
M)$```````"8D0```````-B1```````!&)$```````%8D0```````9B1`````
M``!V)$```````(8D0```````EB1```````"F)$```````+8D0```````QB1`
M``````#6)$```````.8D0```````]B1````````&)4```````!8E0```````
M)B5````````V)4```````$8E0```````5B5```````!F)4```````'8E0```
M````AB5```````"6)4```````*8E0```````MB5```````#&)4```````-8E
M0```````YB5```````#V)4````````8F0```````%B9`````````````````
M````````````_____P````!89$```````.E;````````1T-#.B`H1&5B:6%N
M(#0N-"XU+3@I(#0N-"XU`$=#0SH@*$1E8FEA;B`T+C0N-2TQ,"D@-"XT+C4`
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U
M:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N
M`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O
M<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M````````````````````````````````````````````"P````$````"````
M```````"0`````````(````````<`````````````````````0``````````
M`````````!,````'`````@`````````<`D```````!P"````````(```````
M``````````````0````````````````````A````!P````(`````````/`)`
M```````\`@```````"0````````````````````$````````````````````
M.`````4````"`````````&`"0```````8`(```````!<`P````````8`````
M````"``````````$`````````#0```#V__]O`@````````#`!4```````,`%
M````````6`$````````&``````````@````````````````````^````"P``
M``(`````````&`=````````8!P```````.`*````````!P````$````(````
M`````!@`````````1@````,````"`````````/@10```````^!$```````#I
M!0```````````````````0```````````````````$X```#___]O`@``````
M``#B%T```````.(7````````Z``````````&``````````(``````````@``
M``````!;````_O__;P(`````````T!A```````#0&````````'``````````
M!P````(````(````````````````````:@````0````"`````````$`90```
M````0!D```````!@``````````8`````````"``````````8`````````'0`
M```$`````@````````"@&4```````*`9````````:`<````````&````#0``
M``@`````````&`````````!^`````0````8`````````""%````````((0``
M`````!@````````````````````$````````````````````>0````$````&
M`````````"`A0```````("$`````````!0``````````````````!```````
M```0`````````(0````!````!@`````````@)D```````"`F````````R#H`
M`````````````````!````````````````````"*`````0````8`````````
MZ&!```````#H8`````````X````````````````````$````````````````
M````D`````$````"``````````!A0````````&$```````!*7P``````````
M````````(````````````````````)@````!`````@````````!,P$``````
M`$S`````````[`````````````````````0```````````````````"F````
M`0````(`````````.,%````````XP0```````*P#```````````````````(
M````````````````````L`````$````#`````````.C$8```````Z,0`````
M```0````````````````````"````````````````````+<````!`````P``
M``````#XQ&```````/C$````````$`````````````````````@`````````
M``````````"^`````0````,`````````",5@```````(Q0````````@`````
M```````````````(````````````````````PP````8````#`````````!#%
M8```````$,4```````#P`0````````<`````````"``````````0````````
M`,P````!`````P``````````QV````````#'````````"```````````````
M``````@`````````"`````````#1`````0````,`````````",=@```````(
MQP```````)`"```````````````````(``````````@`````````V@````$`
M```#`````````)C)8```````F,D````````H````````````````````"```
M`````````````````.`````(`````P````````#`R6```````,#)````````
M@!```````````````````"````````````````````#E`````0```#``````
M``````````````#`R0```````#D````````````````````!``````````$`
M`````````0````,`````````````````````````^<D```````#N````````
9`````````````0``````````````````````
